﻿using FlirLepton.Communication;
using FlirLepton.Image;
using FlirLepton.Image.LinearColors;
using System;
using System.Drawing;
using System.IO.Ports;
using System.Windows.Forms;

namespace FlirLepton
{
    public partial class Form1 : Form
    {
        private LeptonConnection leptonConnection;
        private LeptonDraw leptonDraw;
        private Timer timer;

        public Form1()
        {
            InitializeComponent();
            timer = new Timer();
            timer.Tick += LeptonTimerTick;
            timer.Interval = 50;
            leptonDraw = new LeptonDraw(Config.LEPTON_ROWS, Config.LEPTON_COLS, log);
            imagePanel.Controls.Add(leptonDraw);

            LoadSerialPorts();
            LoadColorPalettes();
        }

        private void LoadColorPalettes()
        {
            colorPaletteComboBox.Items.AddRange(Enum.GetNames(typeof(ColorPalettes)));
            colorPaletteComboBox.SelectedIndex = colorPaletteComboBox.Items.Count - 1;
        }

        private void LeptonTimerTick(object sender, EventArgs e)
        {
            if (!leptonConnection.IsPendingResultRequest)
            {
                leptonConnection.RequestResult();
            }

            if (leptonConnection.IsResultReady)
            {
                LeptonImage image = leptonConnection.GetResult();
                leptonDraw.SetImage(image);
            }
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (leptonConnection == null)
            {
                return;
            }

            leptonConnection.Stop();
        }

        private void LoadSerialPorts()
        {
            serialPortsComboBox.Items.Clear();
            serialPortsComboBox.Items.AddRange(SerialPort.GetPortNames());
            serialPortsComboBox.SelectedIndex = serialPortsComboBox.Items.Count - 1;

            log.LogMessage($"Nalazeno COM portů: {serialPortsComboBox.Items.Count}");
        }

        private void loadSerialPortsButton_Click(object sender, EventArgs e)
        {
            LoadSerialPorts();
        }

        private void serialPortsComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (serialPortsComboBox.SelectedIndex > 0)
            {
                connectButton.Enabled = true;
            }
        }

        private void connectButton_Click(object sender, EventArgs e)
        {
            string comPortName = serialPortsComboBox.SelectedItem.ToString();
            leptonConnection = new LeptonConnection(comPortName, Config.LEPTON_ROWS, Config.LEPTON_COLS);
            log.LogMessage($"Připojeno k {comPortName}");
            leptonConnection.Start();
            timer.Start();
        }

        private void colorPaletteComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            string selectedColorPallete = colorPaletteComboBox.SelectedItem.ToString();
            leptonDraw.ColorPallete = (ColorPalettes)Enum.Parse(typeof(ColorPalettes), selectedColorPallete);
        }

        private void screenshotButton_Click(object sender, EventArgs e)
        {
            Bitmap bitmap = leptonDraw.GetBitmap();
            SaveFileDialog fileDialog = new SaveFileDialog();
            fileDialog.FileName = "screenshot.png";
            fileDialog.Filter = "Images|.png";
            if (fileDialog.ShowDialog() == DialogResult.OK)
            {
                bitmap.Save(fileDialog.FileName, System.Drawing.Imaging.ImageFormat.Png);
            }
        }
    }
}