﻿using FlirLepton.Communication;
using System;

namespace FlirLepton.Image
{
    public class LeptonImage
    {
        private double[,] data;
        private int rows;
        private int cols;

        public LeptonImage(int rows, int cols)
        {
            this.rows = rows;
            this.cols = cols;
            data = new double[rows, cols];
        }

        public void SetTempReading(int row, int column, ushort value)
        {
            data[row, column] = ConvertLeptonValue(value);
        }

        private double ConvertLeptonValue(ushort value)
        {
            return Math.Round((value * 0.01) - 273.15, 2);
        }

        public double GetTempReading(int row, int column)
        {
            return data[row, column];
        }

        public TempReading GetMaxTemp()
        {
            return GetTempExtreme(true);
        }

        public TempReading GetMinTemp()
        {
            return GetTempExtreme(false);
        }

        private TempReading GetTempExtreme(bool lookingForMax)
        {
            double tempExtreme = data[0, 0];
            int tempRow = 0;
            int tempCol = 0;

            for (int row = 0; row < rows; row++)
            {
                for (int col = 0; col < cols; col++)
                {
                    double temp = GetTempReading(row, col);
                    if (lookingForMax)
                    {
                        if (temp > tempExtreme)
                        {
                            tempRow = row;
                            tempCol = col;
                            tempExtreme = temp;
                        }
                    }
                    else
                    {
                        if (temp < tempExtreme)
                        {
                            tempRow = row;
                            tempCol = col;
                            tempExtreme = temp;
                        }
                    }
                }
            }

            return new TempReading(tempRow, tempCol, tempExtreme);
        }
    }
}