﻿using System.Collections.Generic;
using System.Drawing;
using System.Linq;

namespace FlirLepton.Image.LinearColors
{
    public class LinearColor
    {
        private List<ColorRange> colorRanges;

        public LinearColor(List<ColorRange> colorRanges)
        {
            this.colorRanges = colorRanges;
        }

        public Color GetColor(double value)
        {
            ColorRange range = colorRanges.FirstOrDefault(x => x.MinValue <= value && x.MaxValue >= value);
            if (range == null)
            {
                throw new LinearColorException();
            }

            return GetGradientColor(range, value);
        }

        private Color GetGradientColor(ColorRange colorRange, double value)
        {
            int r = GetLinearColor(colorRange.MinColor.R, colorRange.MaxColor.R, colorRange.MinValue, colorRange.MaxValue, value);
            int g = GetLinearColor(colorRange.MinColor.G, colorRange.MaxColor.G, colorRange.MinValue, colorRange.MaxValue, value);
            int b = GetLinearColor(colorRange.MinColor.B, colorRange.MaxColor.B, colorRange.MinValue, colorRange.MaxValue, value);

            return Color.FromArgb(r, g, b);
        }

        private int GetLinearColor(int from, int to, double minValue, double maxValue, double value)
        {
            double a = (to - from) / ((double)maxValue - minValue);
            double b = from - (a * minValue);
            return (int)(a * value + b);
        }
    }
}