﻿using System.Collections.Generic;
using System.Drawing;

namespace FlirLepton.Image.LinearColors
{
    public class LinearColorBuilder
    {
        private double maxValue;
        private double minValue;
        private Color lastMinColor;
        private double lastMinValue;
        private List<ColorRange> colorRanges;

        private double DeltaValue => maxValue - minValue;

        public LinearColorBuilder(double minValue, double maxValue, Color minColor)
        {
            this.maxValue = maxValue;
            this.minValue = minValue;
            lastMinColor = minColor;
            lastMinValue = minValue;
            colorRanges = new List<ColorRange>();
        }

        public LinearColorBuilder AddColorRange(Color color, double percentage)
        {
            double newMaxValue = (DeltaValue * percentage) + lastMinValue;
            ColorRange colorRange = new ColorRange(lastMinColor, color, lastMinValue, newMaxValue);
            colorRanges.Add(colorRange);
            lastMinValue = newMaxValue;
            lastMinColor = color;
            return this;
        }

        public LinearColorBuilder AddColorRange(Color color)
        {
            ColorRange colorRange = new ColorRange(lastMinColor, color, lastMinValue, maxValue);
            colorRanges.Add(colorRange);
            return this;
        }

        public LinearColor Make()
        {
            return new LinearColor(colorRanges);
        }
    }
}