﻿using System.Drawing;

namespace FlirLepton.Image.LinearColors
{
    public class LinearColorFactory
    {
        public LinearColor GetLinearColor(ColorPalettes colorPallete, double minValue, double maxValue)
        {
            switch(colorPallete)
            {
                case ColorPalettes.GREYSCALE:
                    return GetGreyscale(minValue, maxValue);
                case ColorPalettes.IRON_BOW:
                    return GetIronBow(minValue, maxValue);
                case ColorPalettes.OUTDOOR_ALERT:
                    return GetOutdoorAlert(minValue, maxValue);
                case ColorPalettes.RAINBOW:
                    return GetRainbow(minValue, maxValue);
            }

            return null;
        }

        private LinearColor GetGreyscale(double minValue, double maxValue)
        {
            LinearColorBuilder builder = new LinearColorBuilder(minValue, maxValue, Color.Black);
            builder.AddColorRange(Color.White);
            return builder.Make();
        }

        private LinearColor GetIronBow(double minValue, double maxValue)
        {
            LinearColorBuilder builder = new LinearColorBuilder(minValue, maxValue, Color.Black);
            builder.AddColorRange(Color.FromArgb(9, 0, 110), 1 / (double)17);
            builder.AddColorRange(Color.FromArgb(180, 0, 150), 4 / (double)17);
            builder.AddColorRange(Color.FromArgb(236, 87, 0), 4 / (double)17);
            builder.AddColorRange(Color.FromArgb(255, 200, 0), 4 / (double)17);
            builder.AddColorRange(Color.White);
            return builder.Make();
        }

        private LinearColor GetRainbow(double minValue, double maxValue)
        {
            LinearColorBuilder builder = new LinearColorBuilder(minValue, maxValue, Color.Black);
            builder.AddColorRange(Color.FromArgb(210, 0, 210), 1 / (double)7);
            builder.AddColorRange(Color.FromArgb(0, 5, 181), 1 / (double)7);
            builder.AddColorRange(Color.FromArgb(0, 250, 254), 1 / (double)7);
            builder.AddColorRange(Color.FromArgb(0, 111, 0), 1 / (double)7);
            builder.AddColorRange(Color.FromArgb(253, 254, 0), 1 / (double)7);
            builder.AddColorRange(Color.FromArgb(201, 6, 0), 1 / (double)7);
            builder.AddColorRange(Color.White);
            return builder.Make();
        }

        private LinearColor GetOutdoorAlert(double minValue, double maxValue)
        {
            LinearColorBuilder builder = new LinearColorBuilder(minValue, maxValue, Color.White);
            builder.AddColorRange(Color.Black, 0.9);
            builder.AddColorRange(Color.FromArgb(209,53,47), 0.05);
            builder.AddColorRange(Color.FromArgb(250,238,140));
            return builder.Make();
        }
    }
}